@@ -80,7 +80,7 @@ def get_uri(dirname="data/postgresqlite", driver="pg8000"):
             which we'll set to `pg8000` by default. This parameter allows you to specify a 
             different direct, or leave it out (by providing `None`).
     """
-    get_config(dirname).get_uri(driver)
+    return get_config(dirname).get_uri(driver)
 
 
 def get_config(dirname="data/postgresqlite"):
@@ -131,13 +131,17 @@ def _download_server(config):
     bin_dir = config.expand_path(config.bin_directory)
     os.makedirs(bin_dir, exist_ok=True)
 
-    print(f"Downloading PostgreSQL {config.postgresql_version}")
+    print(f"Downloading PostgreSQL {config.postgresql_version}..", file=sys.stderr)
 
     url = f"https://github.com/vanviegen/postgresqlite/releases/download/libs/standalone-postgresql-{config.postgresql_version}.tar.gz"
     url_stream = urllib.request.urlopen(url)
     tar_stream = tarfile.open(fileobj=url_stream, mode="r|gz")
     tar_stream.extractall(path=bin_dir)
 
+    if not os.path.exists(config.expand_path(config.postgres_bin)):
+        print(f"Download and extract to {bin_dir} failed.", file=sys.stderr)
+        sys.exit(1)
+
 
 def _auto_start(config):
     lockdir = config.directory+"/locks"
@@ -265,14 +269,14 @@ def _run_server(daemon_fd, log_fd, config):
                         locked_by_me = True
                     continue
                 with open(pathname) as fd:
-                    client_count += 1 
                     try:
                         fcntl.flock(fd, fcntl.LOCK_EX | fcntl.LOCK_NB) # Non blocking
                         os.unlink(pathname) # File no longer locked
-                        print(f"PostgreSQLite removed {pathname}", file=log_fd, flush=True)
+                        print(f"PostgreSQLite removed {pathname} as it was no longer locked", file=log_fd, flush=True)
 
                     except OSError:
                         pass # File is still locked
+                        client_count += 1 
 
             if not locked_by_me:
                 print("PostgreSQLite shutting down server as {lockdir}/daemon.lock has gone...", file=log_fd, flush=True)
